// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Services;
using System.Web.Script.Services;
using System.Collections;

namespace AjaxApplication.Services
{
    [ScriptService]
    public class MovieService : System.Web.Services.WebService
    {

        private MoviesDBEntities _entities = new MoviesDBEntities();


        [WebMethod]
        public IEnumerable GetMovies(int categoryId)
        {
            var movies = from m in _entities.MovieSet
                         where m.MovieCategory.Id == categoryId
                         select new {m.Id, m.Title, m.Director, m.DateReleased };
            return movies;
        }

        [WebMethod]
        public List<MovieCategory> GetCategories()
        {
            return _entities.MovieCategorySet.ToList();
        }


        [WebMethod]
        public void SaveChanges(List<Change<Movie>> changeSet)
        {
            foreach (var c in changeSet)
            {

                switch (c.action)
                {
                    case ChangeOperationType.insert:
                        //InsertMovie(c.item);
                        break;
                    case ChangeOperationType.update:
                        UpdateMovie(c.item);
                        break;
                    case ChangeOperationType.remove:
                        //RemoveMovie(c.item);
                        break;
                }
            }
        }


        private void UpdateMovie(Movie movieToUpdate)
        {
            var originalMovie = (from m in _entities.MovieSet
                                 where m.Id == movieToUpdate.Id
                                 select m).FirstOrDefault();
            _entities.ApplyCurrentValues("MovieSet", movieToUpdate);
            _entities.SaveChanges();
        }



    }
}